==> mediawiki-1.12.4.tbz: www/mediawiki/languages/messages/MessagesSm.php <==
<?php
/** Samoan (Gagana Samoa)
 *
 * @ingroup Language
 * @file
 *
 * @author sm.wikipedia.org sysops
 */

$messages = array(
# Dates
'sunday'        => 'Aso sa',
'monday'        => 'Aso-gafua',
'tuesday'       => '‘O le aso lua',
'wednesday'     => 'Aso lulu',
'thursday'      => 'Aso totofi',
'friday'        => 'Aso falaile',
'saturday'      => 'Aso to‘ona‘i',
'sun'           => 'Aso sa',
'mon'           => 'Aso gafua',
'wed'           => 'Aso lulu',
'fri'           => 'Aso falaile',
'january'       => 'Ianuari',
'february'      => 'Fepuari',
'march'         => 'Mati',
'april'         => 'Aperila',
'may_long'      => 'Me',
'june'          => 'Iuni',
'july'          => 'Iulai',
'august'        => 'Aokuso',
'september'     => 'Setema',
'october'       => 'Oketopa',
'november'      => 'Novema',
'december'      => 'Tesema',
'january-gen'   => 'Ianuari',
'february-gen'  => 'Fepuari',
'march-gen'     => 'Mati',
'april-gen'     => 'Aperila',
'may-gen'       => 'Me',
'june-gen'      => 'Iuni',
'july-gen'      => 'Iulai',
'august-gen'    => 'Aokuso',
'september-gen' => 'Setema',
'october-gen'   => 'Oketopa',
'november-gen'  => 'Novema',
'december-gen'  => 'Tesema',
'jan'           => 'Ianuari',
'feb'           => 'Fepuari',
'mar'           => 'Mati',
'apr'           => 'Aperila',
'may'           => 'Me',
'jun'           => 'Iuni',
'jul'           => 'Iulai',
'aug'           => 'Aokuso',
'sep'           => 'Setema',
'oct'           => 'Oketopa',
'nov'           => 'Novema',
'dec'           => 'Tesema',

'cancel'     => 'Toe tape',
'mytalk'     => "La'u talanoa",
'navigation' => 'Ulifolau',

'help'             => 'Fesoasoani',
'search'           => "Su'e",
'searchbutton'     => "Su'e",
'go'               => 'Alu',
'searcharticle'    => 'Alu',
'history_short'    => "Tala fa'asolopito",
'printableversion' => 'Kopi e lolomi',
'permalink'        => "So'otaga tumau",
'print'            => 'Lolomi',
'edit'             => 'Teuteu',
'delete'           => 'Tape',
'protect'          => 'Puipui',
'unprotect'        => "'Aua le Puipuia",
'specialpage'      => "Itulau fa'apitoa",
'talk'             => 'Talanoaga',
'toolbox'          => 'Meafaigaluega',
'otherlanguages'   => 'I isi gagana',
'jumptonavigation' => 'Ulifolau',
'jumptosearch'     => "Su'e",

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'currentevents'     => 'Tala Fou',
'currentevents-url' => 'Project:Tala Fou',
'edithelp'          => 'Fesoasoani e teuteu',
'mainpage'          => 'Itulau Muamua',
'portal'            => 'Vaega mo Tagata Lautele',
'portal-url'        => 'Project:Vaega mo Tagata Lautele',
'sitesupport'       => 'Meaalofa tupe',

'youhavenewmessages'      => "'Ua iai lau $1 ($2).",
'newmessageslink'         => "Poloa'i fou",
'youhavenewmessagesmulti' => "'Ua iai au fe'au fou i le $1",
'editsection'             => 'Teuteu',
'editold'                 => 'Teuteu',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'Tusitusiga',
'nstab-user'      => "Itulau a 'oe",
'nstab-mediawiki' => "Fe'au",

# Login and logout pages
'yourname'          => "Igoa o le tagata fa'aaoga",
'yourpassword'      => "'Upu ulufale",
'yourpasswordagain' => "Toe lolomi 'upu ulufale",
'login'             => "Fa'aola",
'userlogin'         => "Fa'aola / Lesitala le ulufale",
'logout'            => 'Tape',
'userlogout'        => 'Tape',
'notloggedin'       => "Le'i fa'aolaina",
'nologinlink'       => 'Lesitala le ulufale',
'createaccount'     => 'Lesitala le ulufale',
'gotaccountlink'    => "Fa'aola",
'youremail'         => "'Imeli:",
'username'          => "Igoa o le tagata fa'aaoga:",
'email'             => "'Imeli",

# Edit pages
'summary'          => "'Oto'otoga",
'minoredit'        => "'O se teuteuga la'itiiti lenei",
'watchthis'        => 'Matau lenei itulau',
'savearticle'      => 'Sefe le itulau',
'showpreview'      => "Fa'aali teuteuga",
'showdiff'         => "Fa'aali suiga",
'whitelistacctext' => 'To be allowed to create accounts in {{SITENAME}} you have to [[Special:UserLogin|log]] in and have the appropriate permissions.',
'loginreqlink'     => "Fa'aola",

# Search results
'powersearch' => "Su'e",

# Preferences page
'mypreferences'     => "Mea 'ou te fiafia i ai",
'searchresultshead' => "Su'e",

# Groups
'group-all' => "(mea 'uma)",

# Recent changes
'recentchanges' => 'Suiga talu ai nei',
'hist'          => "Tala fa'asolopito",

# Recent changes linked
'recentchangeslinked' => "Suiga e a'afia ai",

# Upload
'upload'            => "Si'i mai le faila",
'uploadbtn'         => "Si'i mai le faila",
'uploadnologin'     => "Le'i fa'aolaina",
'filedesc'          => "'Oto'otoga",
'fileuploadsummary' => "'Oto'otoga:",
'watchthisupload'   => 'Matau lenei itulau',

# Image list
'ilsubmit' => "Su'e",

# Random page
'randompage' => "Itulau le fa'ailogaina",

# Miscellaneous special pages
'specialpages'      => "Itulau fa'apitoa",
'newpages-username' => "Igoa o le tagata fa'aaoga:",
'move'              => "Si'itia",

# Book sources
'booksources-go' => 'Alu',

# Special:Allpages
'allpagessubmit' => 'Alu',

# E-mail user
'emailuser'    => "'Imeli mai le tagata lenei",
'emailmessage' => "Fe'au",

# Watchlist
'watchlist'     => "Lo'u lisi va'ava'aia",
'watchnologin'  => "Le'i fa'aolaina",
'watch'         => "Va'ai",
'watchthispage' => 'Matau lenei itulau',

# Restrictions (nouns)
'restriction-move' => "Si'itia",

# Undelete
'undelete-search-submit' => "Su'e",

# Contributions
'contributions' => "Sao a tagata fa'aaoga",
'mycontris'     => "'O la'u saoga",

# What links here
'whatlinkshere' => "Nofoaga e soso'o mai",

# Block/unblock
'proxyblocksuccess' => "Mae'a.",

# Move page
'movepage'    => "Si'i le itulau",
'movearticle' => "Si'i le itulau",
'movenologin' => "Le'i fa'aolaina",
'newtitle'    => "'I le ulutala fou",
'move-watch'  => 'Matau lenei itulau',
'movepagebtn' => "Si'i le itulau",
'movetalk'    => 'Sui le itulau e tau i ai',
'movereason'  => "Mafua'aga",

# Namespace 8 related
'allmessagesname' => 'Igoa',

# 'all' in various places, this might be different for inflected languages
'recentchangesall' => "mea 'uma",
'imagelistall'     => "mea 'uma",
'watchlistall2'    => "mea 'uma",
'namespacesall'    => "mea 'uma",

# Multipage image navigation
'imgmultigo' => 'Alu!',

# Table pager
'table_pager_limit_submit' => 'Alu',

);

==> mediawiki-1.15.5.tbz: www/mediawiki/languages/messages/MessagesSm.php <==
<?php
/** Samoan (Gagana Samoa)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author sm.wikipedia.org sysops
 */

$messages = array(
# Dates
'sunday'        => 'Aso sa',
'monday'        => 'Aso-gafua',
'tuesday'       => '‘O le aso lua',
'wednesday'     => 'Aso lulu',
'thursday'      => 'Aso totofi',
'friday'        => 'Aso falaile',
'saturday'      => 'Aso to‘ona‘i',
'sun'           => 'Aso sa',
'mon'           => 'Aso gafua',
'wed'           => 'Aso lulu',
'fri'           => 'Aso falaile',
'january'       => 'Ianuari',
'february'      => 'Fepuari',
'march'         => 'Mati',
'april'         => 'Aperila',
'may_long'      => 'Me',
'june'          => 'Iuni',
'july'          => 'Iulai',
'august'        => 'Aokuso',
'september'     => 'Setema',
'october'       => 'Oketopa',
'november'      => 'Novema',
'december'      => 'Tesema',
'january-gen'   => 'Ianuari',
'february-gen'  => 'Fepuari',
'march-gen'     => 'Mati',
'april-gen'     => 'Aperila',
'may-gen'       => 'Me',
'june-gen'      => 'Iuni',
'july-gen'      => 'Iulai',
'august-gen'    => 'Aokuso',
'september-gen' => 'Setema',
'october-gen'   => 'Oketopa',
'november-gen'  => 'Novema',
'december-gen'  => 'Tesema',
'jan'           => 'Ianuari',
'feb'           => 'Fepuari',
'mar'           => 'Mati',
'apr'           => 'Aperila',
'may'           => 'Me',
'jun'           => 'Iuni',
'jul'           => 'Iulai',
'aug'           => 'Aokuso',
'sep'           => 'Setema',
'oct'           => 'Oketopa',
'nov'           => 'Novema',
'dec'           => 'Tesema',

'cancel'     => 'Toe tape',
'mytalk'     => "La'u talanoa",
'navigation' => 'Ulifolau',

'help'             => 'Fesoasoani',
'search'           => "Su'e",
'searchbutton'     => "Su'e",
'go'               => 'Alu',
'searcharticle'    => 'Alu',
'history_short'    => "Tala fa'asolopito",
'printableversion' => 'Kopi e lolomi',
'permalink'        => "So'otaga tumau",
'print'            => 'Lolomi',
'edit'             => 'Teuteu',
'delete'           => 'Tape',
'protect'          => 'Puipui',
'unprotect'        => "'Aua le Puipuia",
'specialpage'      => "Itulau fa'apitoa",
'talk'             => 'Talanoaga',
'toolbox'          => 'Meafaigaluega',
'otherlanguages'   => 'I isi gagana',
'jumptonavigation' => 'Ulifolau',
'jumptosearch'     => "Su'e",

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'currentevents'        => 'Tala Fou',
'currentevents-url'    => 'Project:Tala Fou',
'edithelp'             => 'Fesoasoani e teuteu',
'mainpage'             => 'Itulau Muamua',
'mainpage-description' => 'Itulau Muamua',
'portal'               => 'Vaega mo Tagata Lautele',
'portal-url'           => 'Project:Vaega mo Tagata Lautele',

'youhavenewmessages'      => "'Ua iai lau $1 ($2).",
'newmessageslink'         => "Poloa'i fou",
'youhavenewmessagesmulti' => "'Ua iai au fe'au fou i le $1",
'editsection'             => 'Teuteu',
'editold'                 => 'Teuteu',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'Tusitusiga',
'nstab-user'      => "Itulau a 'oe",
'nstab-mediawiki' => "Fe'au",

# Login and logout pages
'yourname'          => "Igoa o le tagata fa'aaoga",
'yourpassword'      => "'Upu ulufale",
'yourpasswordagain' => "Toe lolomi 'upu ulufale",
'login'             => "Fa'aola",
'userlogin'         => "Fa'aola / Lesitala le ulufale",
'logout'            => 'Tape',
'userlogout'        => 'Tape',
'notloggedin'       => "Le'i fa'aolaina",
'nologinlink'       => 'Lesitala le ulufale',
'createaccount'     => 'Lesitala le ulufale',
'gotaccountlink'    => "Fa'aola",
'youremail'         => "'Imeli:",
'username'          => "Igoa o le tagata fa'aaoga:",
'email'             => "'Imeli",

# Edit pages
'summary'      => "'Oto'otoga:",
'minoredit'    => "'O se teuteuga la'itiiti lenei",
'watchthis'    => 'Matau lenei itulau',
'savearticle'  => 'Sefe le itulau',
'showpreview'  => "Fa'aali teuteuga",
'showdiff'     => "Fa'aali suiga",
'loginreqlink' => "Fa'aola",

# Search results
'powersearch' => "Su'e",

# Preferences page
'mypreferences'     => "Mea 'ou te fiafia i ai",
'searchresultshead' => "Su'e",

# Groups
'group-all' => "(mea 'uma)",

# Recent changes
'recentchanges' => 'Suiga talu ai nei',
'hist'          => "Tala fa'asolopito",

# Recent changes linked
'recentchangeslinked' => "Suiga e a'afia ai",

# Upload
'upload'            => "Si'i mai le faila",
'uploadbtn'         => "Si'i mai le faila",
'uploadnologin'     => "Le'i fa'aolaina",
'filedesc'          => "'Oto'otoga",
'fileuploadsummary' => "'Oto'otoga:",
'watchthisupload'   => 'Matau lenei itulau',

# Random page
'randompage' => "Itulau le fa'ailogaina",

# Miscellaneous special pages
'newpages-username' => "Igoa o le tagata fa'aaoga:",
'move'              => "Si'itia",

# Book sources
'booksources-go' => 'Alu',

# Special:AllPages
'allpagessubmit' => 'Alu',

# E-mail user
'emailuser'    => "'Imeli mai le tagata lenei",
'emailmessage' => "Fe'au",

# Watchlist
'watchlist'     => "Lo'u lisi va'ava'aia",
'watchnologin'  => "Le'i fa'aolaina",
'watch'         => "Va'ai",
'watchthispage' => 'Matau lenei itulau',

# Restrictions (nouns)
'restriction-move' => "Si'itia",

# Undelete
'undelete-search-submit' => "Su'e",

# Contributions
'contributions' => "Sao a tagata fa'aaoga",
'mycontris'     => "'O la'u saoga",

# What links here
'whatlinkshere' => "Nofoaga e soso'o mai",

# Block/unblock
'proxyblocksuccess' => "Mae'a.",

# Move page
'move-page-legend' => "Si'i le itulau",
'movearticle'      => "Si'i le itulau",
'movenologin'      => "Le'i fa'aolaina",
'newtitle'         => "'I le ulutala fou",
'move-watch'       => 'Matau lenei itulau',
'movepagebtn'      => "Si'i le itulau",
'movetalk'         => 'Sui le itulau e tau i ai',
'movereason'       => "Mafua'aga",

# Namespace 8 related
'allmessagesname' => 'Igoa',

# Special:NewFiles
'ilsubmit' => "Su'e",

# 'all' in various places, this might be different for inflected languages
'recentchangesall' => "mea 'uma",
'imagelistall'     => "mea 'uma",
'watchlistall2'    => "mea 'uma",
'namespacesall'    => "mea 'uma",

# Multipage image navigation
'imgmultigo' => 'Alu!',

# Table pager
'table_pager_limit_submit' => 'Alu',

# Special:SpecialPages
'specialpages' => "Itulau fa'apitoa",

);
